@@ -22,7 +22,7 @@ var linkTypes = {
 
     // constants. Also available in lib/ui_info.js
     'CERTAIN_EMAIL_ADDRESS_FOUND': 'certainEmailAddressFound',
-    'UNCERTAIN_EMAIL_ADDRESS_FOUND': 'uncertainEmailAddresFound',
+    'UNCERTAIN_EMAIL_ADDRESS_FOUND': 'uncertainEmailAddressFound',
 
     // Looking for contact links
     'CERTAIN_LINK_FOUND': 'certainLinkFound',
