@@ -30,6 +30,10 @@ var data = require("self").data;
 // identifiers.
 var licenses = require('js_checker/license_definitions').licenses;
 
+// keep web labels in memory so that they can be checked even when they
+// are embedded dynamically.
+var jsWebLabelEntries = {};
+
 var webLabelFinder = {
 
     dom: null,
@@ -102,6 +106,10 @@ var webLabelFinder = {
 
 		    that.matchListWithDefs();
 
+		    // add these entries to the global
+		    // object for dynamically embedded scripts.
+		    jsWebLabelEntries[that.pageURL] = that.licenseList;
+
 		    // return array to requester object
 		    that.callback(that.licenseList);
 
@@ -141,4 +149,7 @@ var webLabelFinder = {
     }
 };
 
-exports.webLabelFinder = webLabelFinder;
\ No newline at end of file
+exports.webLabelFinder = webLabelFinder;
+
+// store the web labels harvested across webpages (single session).
+exports.jsWebLabelEntries = jsWebLabelEntries;
